==> zio-aws-s3control_2.12-7.21.15.12-sources.jar: zio/aws/s3control/model/PolicyStatus.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.s3control.model.primitives.IsPublic
import scala.jdk.CollectionConverters._
final case class PolicyStatus(isPublic: Optional[IsPublic] = Optional.Absent) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.PolicyStatus = {
    import PolicyStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.PolicyStatus
      .builder()
      .optionallyWith(
        isPublic.map(value => IsPublic.unwrap(value): java.lang.Boolean)
      )(_.isPublic)
      .build()
  }
  def asReadOnly: zio.aws.s3control.model.PolicyStatus.ReadOnly =
    zio.aws.s3control.model.PolicyStatus.wrap(buildAwsValue())
}
object PolicyStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3control.model.PolicyStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3control.model.PolicyStatus =
      zio.aws.s3control.model.PolicyStatus(isPublic.map(value => value))
    def isPublic: Optional[IsPublic]
    def getIsPublic: ZIO[Any, AwsError, IsPublic] =
      AwsError.unwrapOptionField("isPublic", isPublic)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.PolicyStatus
  ) extends zio.aws.s3control.model.PolicyStatus.ReadOnly {
    override val isPublic: Optional[IsPublic] = zio.aws.core.internal
      .optionalFromNullable(impl.isPublic())
      .map(value => zio.aws.s3control.model.primitives.IsPublic(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.PolicyStatus
  ): zio.aws.s3control.model.PolicyStatus.ReadOnly = new Wrapper(impl)
}

==> zio-aws-s3control_2.13-5.17.160.1-sources.jar: zio/aws/s3control/model/PolicyStatus.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.s3control.model.primitives.IsPublic
import scala.jdk.CollectionConverters._
final case class PolicyStatus(isPublic: Option[IsPublic] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.PolicyStatus = {
    import PolicyStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.PolicyStatus
      .builder()
      .optionallyWith(
        isPublic.map(value => IsPublic.unwrap(value): java.lang.Boolean)
      )(_.isPublic)
      .build()
  }
  def asReadOnly: zio.aws.s3control.model.PolicyStatus.ReadOnly =
    zio.aws.s3control.model.PolicyStatus.wrap(buildAwsValue())
}
object PolicyStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3control.model.PolicyStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3control.model.PolicyStatus =
      zio.aws.s3control.model.PolicyStatus(isPublic.map(value => value))
    def isPublic: Option[IsPublic]
    def getIsPublic: ZIO[Any, AwsError, IsPublic] =
      AwsError.unwrapOptionField("isPublic", isPublic)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.PolicyStatus
  ) extends zio.aws.s3control.model.PolicyStatus.ReadOnly {
    override val isPublic: Option[IsPublic] = scala
      .Option(impl.isPublic())
      .map(value => zio.aws.s3control.model.primitives.IsPublic(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.PolicyStatus
  ): zio.aws.s3control.model.PolicyStatus.ReadOnly = new Wrapper(impl)
}
